Stan Math Library: stan/math/prim/scal/fun/int_step.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

int_step.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_INT_STEP_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_INT_STEP_HPP
3
4 namespace stan {
5 namespace math {
24 template <typename T>
25 unsigned int int_step(const T y) {
26 return y > 0;
27 }
28 }
29 }
30
31 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::int_step
unsigned int int_step(const T y)
The integer step, or Heaviside, function.
Definition: int_step.hpp:25

[ Stan Home Page ] © 2011–2016, Stan Development Team.